==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/language/nl/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Remote Invocation";
$GLOBALS['strInvocationJS']			= "Remote Invocation voor Javascript";
$GLOBALS['strInvocationIframes']		= "Remote Invocation voor iframes";
$GLOBALS['strInvocationXmlRpc']			= "Remote Invocation voor XML-RPC";
$GLOBALS['strInvocationCombined']		= "Gecombineerde Remote Invocation";
$GLOBALS['strInvocationPopUp']			= "Pop-up";
$GLOBALS['strInvocationAdLayer']		= "Interstitial of Floating DHTML";
$GLOBALS['strInvocationLocal']			= "Lokale mode";


// Other
$GLOBALS['strCopyToClipboard']			= "Kopieer naar klembord";


// Measures
$GLOBALS['strAbbrPixels']			= "px";
$GLOBALS['strAbbrSeconds']			= "sec";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Banner selectie";
$GLOBALS['strInvocationClientID']		= "Adverteerder of campagne";
$GLOBALS['strInvocationTarget']			= "Doel frame";
$GLOBALS['strInvocationSource']			= "Bron";
$GLOBALS['strInvocationWithText']		= "Toon text";
$GLOBALS['strInvocationDontShowAgainCampaign']		= "Toon niet nog eens een banner van dezelfde campagne op dezelfde pagina";
$GLOBALS['strInvocationDontShowAgain']		= "Toon deze banner niet nog eens op dezelfde pagina";
$GLOBALS['strInvocationTemplate'] 		= "Sla de banner op in een variable welke gebruikt van worden in een sjabloon";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Ververs na";
$GLOBALS['strIframeResizeToBanner']		= "Pas de groote van iframe aan de banner";
$GLOBALS['strIframeMakeTransparent']		= "Maak de iframe transparant";
$GLOBALS['strIframeIncludeNetscape4']		= "Voeg Netscape 4 compatible ilayer toe";


// PopUp
$GLOBALS['strPopUpStyle']			= "Pop-up type";
$GLOBALS['strPopUpStylePopUp']			= "Pop-up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-under";
$GLOBALS['strPopUpCreateInstance']		= "Moment waarop de pop-up getoond wordt";
$GLOBALS['strPopUpImmediately']			= "Direct";
$GLOBALS['strPopUpOnClose']			= "Na het sluiten van de pagina";
$GLOBALS['strPopUpAfterSec']			= "Na";
$GLOBALS['strAutoCloseAfter']			= "Sluit automatisch na";
$GLOBALS['strPopUpTop']				= "Begin positie (boven)";
$GLOBALS['strPopUpLeft']			= "Begin positie (links)";
$GLOBALS['strWindowOptions']			= "Window opties";
$GLOBALS['strShowToolbars']			= "Werkbalken";
$GLOBALS['strShowLocation']			= "Locatiebalk";
$GLOBALS['strShowMenubar']			= "Menubalk";
$GLOBALS['strShowStatus']			= "Statusbalk";
$GLOBALS['strWindowResizable']			= "Aanpassen grootte";
$GLOBALS['strShowScrollbars']			= "Schuifbalken";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Scripttaal";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "Layer stijl";

$GLOBALS['strAlignment']			= "Uitlijning";
$GLOBALS['strHAlignment']			= "Horizontaal uitlijnen";
$GLOBALS['strLeft']				= "Links";
$GLOBALS['strCenter']				= "Centreer";
$GLOBALS['strRight']				= "Rechts";

$GLOBALS['strVAlignment']			= "Verticaal uitlijnen";
$GLOBALS['strTop']				= "Boven";
$GLOBALS['strMiddle']				= "Midden";
$GLOBALS['strBottom']				= "Onder";

$GLOBALS['strAutoCollapseAfter']		= "Automatisch inklappen na";
$GLOBALS['strCloseText']			= "Sluit tekst";
$GLOBALS['strClose']				= "[Sluit]";
$GLOBALS['strBannerPadding']			= "Banner afstand";

$GLOBALS['strHShift']				= "Horizontaal verplaatsen";
$GLOBALS['strVShift']				= "Vertikaal verplaatsen";

$GLOBALS['strShowCloseButton']			= "Toon sluit knop";
$GLOBALS['strBackgroundColor']			= "Achtergrond kleur";
$GLOBALS['strBorderColor']			= "Rand kleur";

$GLOBALS['strDirection']			= "Richting";
$GLOBALS['strLeftToRight']			= "Van links naar rechts";
$GLOBALS['strRightToLeft']			= "Van rechts naar links";
$GLOBALS['strLooping']				= "Herhalend";
$GLOBALS['strAlwaysActive']			= "Altijd actief";
$GLOBALS['strSpeed']				= "Snelheid";
$GLOBALS['strPause']				= "Pauze";
$GLOBALS['strLimited']				= "Gelimiteerd";
$GLOBALS['strLeftMargin']			= "Linker marge";
$GLOBALS['strRightMargin']			= "Rechter marge";
$GLOBALS['strTransparentBackground']		= "Transparante achtergrond";

$GLOBALS['strSmoothMovement']		= "Elasticiteit";
$GLOBALS['strHideNotMoving']		= "Verberg de banner wanneer de muiscursor niet beweegt";
$GLOBALS['strHideDelay']			= "Tijd voordat de banner verborgen wordt";
$GLOBALS['strHideTransparancy']		= "Transparantie van de verborgen banner";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Simpel",
	'cursor'		=> "Muiscursor",
	'floater'		=> "Floater"
);

?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/language/nl/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Remote Invocation";
$GLOBALS['strInvocationJS']			= "Remote Invocation voor Javascript";
$GLOBALS['strInvocationIframes']		= "Remote Invocation voor iframes";
$GLOBALS['strInvocationXmlRpc']			= "Remote Invocation voor XML-RPC";
$GLOBALS['strInvocationCombined']		= "Gecombineerde Remote Invocation";
$GLOBALS['strInvocationPopUp']			= "Pop-up";
$GLOBALS['strInvocationAdLayer']		= "Interstitial of Floating DHTML";
$GLOBALS['strInvocationLocal']			= "Lokale mode";


// Other
$GLOBALS['strCopyToClipboard']			= "Kopieer naar klembord";


// Measures
$GLOBALS['strAbbrPixels']			= "px";
$GLOBALS['strAbbrSeconds']			= "sec";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Banner selectie";
$GLOBALS['strInvocationClientID']		= "Adverteerder of campagne";
$GLOBALS['strInvocationTarget']			= "Doel frame";
$GLOBALS['strInvocationSource']			= "Bron";
$GLOBALS['strInvocationWithText']		= "Toon text";
$GLOBALS['strInvocationDontShowAgainCampaign']		= "Toon niet nog eens een banner van dezelfde campagne op dezelfde pagina";
$GLOBALS['strInvocationDontShowAgain']		= "Toon deze banner niet nog eens op dezelfde pagina";
$GLOBALS['strInvocationTemplate'] 		= "Sla de banner op in een variable welke gebruikt van worden in een sjabloon";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Ververs na";
$GLOBALS['strIframeResizeToBanner']		= "Pas de groote van iframe aan de banner";
$GLOBALS['strIframeMakeTransparent']		= "Maak de iframe transparant";
$GLOBALS['strIframeIncludeNetscape4']		= "Voeg Netscape 4 compatible ilayer toe";


// PopUp
$GLOBALS['strPopUpStyle']			= "Pop-up type";
$GLOBALS['strPopUpStylePopUp']			= "Pop-up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-under";
$GLOBALS['strPopUpCreateInstance']		= "Moment waarop de pop-up getoond wordt";
$GLOBALS['strPopUpImmediately']			= "Direct";
$GLOBALS['strPopUpOnClose']			= "Na het sluiten van de pagina";
$GLOBALS['strPopUpAfterSec']			= "Na";
$GLOBALS['strAutoCloseAfter']			= "Sluit automatisch na";
$GLOBALS['strPopUpTop']				= "Begin positie (boven)";
$GLOBALS['strPopUpLeft']			= "Begin positie (links)";
$GLOBALS['strWindowOptions']			= "Window opties";
$GLOBALS['strShowToolbars']			= "Werkbalken";
$GLOBALS['strShowLocation']			= "Locatiebalk";
$GLOBALS['strShowMenubar']			= "Menubalk";
$GLOBALS['strShowStatus']			= "Statusbalk";
$GLOBALS['strWindowResizable']			= "Aanpassen grootte";
$GLOBALS['strShowScrollbars']			= "Schuifbalken";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Scripttaal";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "Layer stijl";

$GLOBALS['strAlignment']			= "Uitlijning";
$GLOBALS['strHAlignment']			= "Horizontaal uitlijnen";
$GLOBALS['strLeft']				= "Links";
$GLOBALS['strCenter']				= "Centreer";
$GLOBALS['strRight']				= "Rechts";

$GLOBALS['strVAlignment']			= "Verticaal uitlijnen";
$GLOBALS['strTop']				= "Boven";
$GLOBALS['strMiddle']				= "Midden";
$GLOBALS['strBottom']				= "Onder";

$GLOBALS['strAutoCollapseAfter']		= "Automatisch inklappen na";
$GLOBALS['strCloseText']			= "Sluit tekst";
$GLOBALS['strClose']				= "[Sluit]";
$GLOBALS['strBannerPadding']			= "Banner afstand";

$GLOBALS['strHShift']				= "Horizontaal verplaatsen";
$GLOBALS['strVShift']				= "Vertikaal verplaatsen";

$GLOBALS['strShowCloseButton']			= "Toon sluit knop";
$GLOBALS['strBackgroundColor']			= "Achtergrond kleur";
$GLOBALS['strBorderColor']			= "Rand kleur";

$GLOBALS['strDirection']			= "Richting";
$GLOBALS['strLeftToRight']			= "Van links naar rechts";
$GLOBALS['strRightToLeft']			= "Van rechts naar links";
$GLOBALS['strLooping']				= "Herhalend";
$GLOBALS['strAlwaysActive']			= "Altijd actief";
$GLOBALS['strSpeed']				= "Snelheid";
$GLOBALS['strPause']				= "Pauze ";
$GLOBALS['strLimited']				= "Gelimiteerd";
$GLOBALS['strLeftMargin']			= "Linker marge";
$GLOBALS['strRightMargin']			= "Rechter marge";
$GLOBALS['strTransparentBackground']		= "Transparante achtergrond";

$GLOBALS['strSmoothMovement']		= "Elasticiteit";
$GLOBALS['strHideNotMoving']		= "Verberg de banner wanneer de muiscursor niet beweegt";
$GLOBALS['strHideDelay']			= "Tijd voordat de banner verborgen wordt";
$GLOBALS['strHideTransparancy']		= "Transparantie van de verborgen banner";


$GLOBALS['strAdLayerStyleName']['geocities'] = "Geocities";
$GLOBALS['strAdLayerStyleName']['simple'] = "Simpel";
$GLOBALS['strAdLayerStyleName']['cursor'] = "Muiscursor";
$GLOBALS['strAdLayerStyleName']['floater'] = "Floater";




// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strInvocationCampaignID'] = "Campagne";
$GLOBALS['strCopy'] = "Kopieer";
$GLOBALS['strChooseTypeOfInvocation'] = "Kies het type banner invocatie";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "Kies het type banner invocatie";
?>
